import { defaultTheme } from "./models/theme";
import _Vue, { PluginFunction } from "vue"; // <-- notice the changed import

import UiTimeline from "./components/timeline/Timeline.vue";
import UiTitle from "./components/shared/Title.vue";
import UiCard from "./components/shared/Card.vue";
import UiIcon from "./components/shared/Icon.vue";
import UiJumbotron from "./components/Jumbotron.vue";
import UiScrollDetector from "./components/shared/ScrollDetector.vue";

import { PluginOptions } from "./models/PluginOptions";

// export type PluginFunction<T> = (Vue: typeof _Vue, options?: T) => void;
const UiComponentPlugin: PluginFunction<PluginOptions> = (
  Vue: typeof _Vue,
  options?: PluginOptions
): void => {
  const libPrefix = "Ui";

  // register components
  const components = {
    UiTimeline,
    UiCard,
    UiTitle,
    UiIcon,
    UiJumbotron,
    UiScrollDetector
  };

  Object.keys(components).forEach(name =>
    Vue.component(name, (components as any)[name])
  );

  // register theme, use default and override supplied theme options
  Vue.prototype.$uiTheme = {
    ...defaultTheme,
    ...options
  };
};

export default UiComponentPlugin;
